<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Microsoft.UI.Xaml.Navigation

ATTENTION: This package has been renamed to
[winui3-Microsoft.UI.Xaml.Navigation](https://pypi.org/project/winui3-Microsoft.UI.Xaml.Navigation/).
Use the new package for the latest updates.

Windows Runtime (WinRT) APIs for for the `Microsoft.UI.Xaml.Navigation` namespace.

This package provides the `winrt.microsoft.ui.xaml.navigation` module.
